import { __decorate, __param, __metadata } from 'tslib';
import { CommonModule } from '@angular/common';
import { InjectionToken, NgModule, Inject, ɵɵdefineInjectable, ɵɵinject, Injectable } from '@angular/core';
import Code from '@editorjs/code';
import Embed from '@editorjs/embed';
import Header from '@editorjs/header';
import Image from '@editorjs/image';
import InlineCode from '@editorjs/inline-code';
import Link from '@editorjs/link';
import List from '@editorjs/list';
import Marker from '@editorjs/paragraph';
import Quote from '@editorjs/quote';
import SimpleImage from '@editorjs/simple-image';
import Warning from '@editorjs/warning';

/**
 * The types of plugins supported, currently block and inline
 */
var PluginTypes;
(function (PluginTypes) {
    /**
     * A EditorJS block plugin
     */
    PluginTypes["Block"] = "block";
    /**
     * A EditorJS inline plugin
     */
    PluginTypes["Inline"] = "inline";
})(PluginTypes || (PluginTypes = {}));
/**
 * The Injection token for initial plugins as defined in the ngx-editorjs module
 */
const EDITOR_JS_TOOL_INJECTOR = new InjectionToken('EDITOR_JS_TOOL_INJECTOR');
/**
 * Injection token for a plugin config
 */
const PLUGIN_CONFIG = new InjectionToken('PLUGIN_CONFIG');
/**
 * Injection token for the plugin config map
 */
const PluginClasses = new InjectionToken('PluginClasses');

const ɵ0 = Code, ɵ1 = {
    key: 'code',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Code'
};
/**
 * A module that provides the default EditorJS `<code>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/code) for API details
 */
let PluginCodeModule = class PluginCodeModule {
};
PluginCodeModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1,
                multi: true
            }
        ]
    })
], PluginCodeModule);

const ɵ0$1 = Embed, ɵ1$1 = {
    key: 'embed',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Embed Block',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
let PluginEmbedModule = class PluginEmbedModule {
};
PluginEmbedModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$1,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$1,
                multi: true
            }
        ]
    })
], PluginEmbedModule);

const ɵ0$2 = Header, ɵ1$2 = {
    key: 'header',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Header'
};
/**
 * A module that provides the default EditorJS header block tool.
 * See [the GitHub repo](https://github.com/editor-js/header) for API details
 */
let PluginHeaderModule = class PluginHeaderModule {
};
PluginHeaderModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$2,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$2,
                multi: true
            }
        ]
    })
], PluginHeaderModule);

const ɵ0$3 = Image, ɵ1$3 = {
    key: 'image',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Image'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
let PluginImageModule = class PluginImageModule {
};
PluginImageModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$3,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$3,
                multi: true
            }
        ]
    })
], PluginImageModule);

const ɵ0$4 = InlineCode, ɵ1$4 = {
    key: 'inline-code',
    type: PluginTypes.Inline,
    pluginName: 'EditorJS Inline Code',
    shortcut: 'CTRL+SHIFT+C'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
let PluginInlineCodeModule = class PluginInlineCodeModule {
};
PluginInlineCodeModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$4,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$4,
                multi: true
            }
        ]
    })
], PluginInlineCodeModule);

const ɵ0$5 = Link, ɵ1$5 = {
    key: 'link',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Link'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
let PluginLinkModule = class PluginLinkModule {
};
PluginLinkModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$5,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$5,
                multi: true
            }
        ]
    })
], PluginLinkModule);

const ɵ0$6 = List, ɵ1$6 = {
    key: 'list',
    type: PluginTypes.Block,
    pluginName: 'EditorJS List'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
let PluginListModule = class PluginListModule {
};
PluginListModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$6,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$6,
                multi: true
            }
        ]
    })
], PluginListModule);

const ɵ0$7 = Marker, ɵ1$7 = {
    key: 'paragraph',
    type: PluginTypes.Inline,
    pluginName: 'EditorJS Marker',
    shortcut: 'CTRL+SHIFT+M'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
let PluginMarkerModule = class PluginMarkerModule {
};
PluginMarkerModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$7,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$7,
                multi: true
            }
        ]
    })
], PluginMarkerModule);

const ɵ0$8 = Marker, ɵ1$8 = {
    key: 'paragraph',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Paragraph'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
let PluginParagraphModule = class PluginParagraphModule {
};
PluginParagraphModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$8,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$8,
                multi: true
            }
        ]
    })
], PluginParagraphModule);

const ɵ0$9 = Quote, ɵ1$9 = {
    key: 'quote',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Quote Tool',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
let PluginQuoteModule = class PluginQuoteModule {
};
PluginQuoteModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$9,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$9,
                multi: true
            }
        ]
    })
], PluginQuoteModule);

const ɵ0$a = SimpleImage, ɵ1$a = {
    key: 'simpleimage',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Simple Image'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
let PluginSimpleImageModule = class PluginSimpleImageModule {
};
PluginSimpleImageModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$a,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$a,
                multi: true
            }
        ]
    })
], PluginSimpleImageModule);

const ɵ0$b = Warning, ɵ1$b = {
    key: 'warning',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Warning Block',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
let PluginWarningModule = class PluginWarningModule {
};
PluginWarningModule = __decorate([
    NgModule({
        providers: [
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ0$b,
                multi: true
            },
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ1$b,
                multi: true
            }
        ]
    })
], PluginWarningModule);

/**
 * Factory function to create the plugin config map for the plugin service
 * @param pluginConfigs The array of plugin configuration objects passed to this factory
 * @param plugins The array of `EditorJS` plugins that are passed to this factory
 */
function createPluginConfig(pluginConfigs, plugins) {
    return pluginConfigs.reduce((pluginConfig, config, index) => typeof config === 'undefined'
        ? pluginConfig
        : Object.assign(Object.assign({}, pluginConfig), { [config.key]: Object.assign(Object.assign({}, config), { plugin: plugins[index] }) }), {});
}

/**
 * The `NgxEditorJSPluginService` is provided as a root service for handling {@link https://github.com/editor-js | EditorJS plugins}.
 *
 * Plugins are provided by using {@link https://angular.io/api/core/NgModule | NgModule} to inject the plugin with a
 * {@link ../interfaces/PluginConfig.html | PluginConfig} using providers.
 */
let NgxEditorJSPluginService = class NgxEditorJSPluginService {
    /**
     * @param pluginConfigMap The plugin configuration map injected into the application
     */
    constructor(pluginConfigMap) {
        this.pluginConfigMap = pluginConfigMap;
    }
    /**
     * Get a map of all plugin configurations
     * @returns The map of plugins injected into this plugin
     */
    getPlugins() {
        return this.pluginConfigMap;
    }
    /**
     * Get a plugin configuration via it's key
     * @param key The key of the plugin to get
     * @returns The plugin configuration for the passed key
     */
    getPlugin(key) {
        return this.pluginConfigMap[key];
    }
    /**
     * Get a list of plugins, filtering with an exclude list of plugins
     * @param excludeList
     */
    getPluginsWithExclude(excludeList = []) {
        return Object.entries(this.pluginConfigMap)
            .filter(([key]) => {
            return !excludeList.includes(key);
        })
            .reduce((pluginMap, [key, plugin]) => {
            return Object.assign(Object.assign({}, pluginMap), { [key]: plugin });
        }, {});
    }
    /**
     * Get a list of plugins, filtering with an include list of plugins
     * @param includeList
     */
    getPluginsWithInclude(includeList = []) {
        return Object.entries(this.pluginConfigMap)
            .filter(([key]) => {
            return includeList.includes(key);
        })
            .reduce((pluginMap, [key, plugin]) => {
            return Object.assign(Object.assign({}, pluginMap), { [key]: plugin });
        }, {});
    }
    /**
     * Returns a map of {@link https://editorjs.io/api | EditorJS} tools to be initialized by the editor
     * @param excludeTools Optional array of tools to exclude, if not passed all tools
     */
    getTools(excludeTools = []) {
        return Object.entries(this.getPluginsWithExclude(excludeTools)).reduce((finalTools, [key, plugin]) => {
            const tool = {
                class: plugin.plugin
            };
            if (plugin.shortcut)
                tool.shortcut = plugin.shortcut;
            if (plugin.type === 'inline' || plugin.inlineToolbar)
                tool.inlineToolbar = true;
            if (plugin.config)
                tool.config = plugin.config;
            return Object.assign(Object.assign({}, finalTools), { [key]: tool });
        }, {});
    }
};
NgxEditorJSPluginService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [PluginClasses,] }] }
];
NgxEditorJSPluginService.ɵprov = ɵɵdefineInjectable({ factory: function NgxEditorJSPluginService_Factory() { return new NgxEditorJSPluginService(ɵɵinject(PluginClasses)); }, token: NgxEditorJSPluginService, providedIn: "root" });
NgxEditorJSPluginService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(PluginClasses)),
    __metadata("design:paramtypes", [Object])
], NgxEditorJSPluginService);

const ɵ0$c = undefined, ɵ1$c = undefined, ɵ2 = createPluginConfig;
let NgxEditorJSPluginServiceModule = class NgxEditorJSPluginServiceModule {
};
NgxEditorJSPluginServiceModule = __decorate([
    NgModule({
        providers: [
            {
                provide: PLUGIN_CONFIG,
                useValue: ɵ0$c,
                multi: true
            },
            {
                provide: EDITOR_JS_TOOL_INJECTOR,
                useValue: ɵ1$c,
                multi: true
            },
            {
                provide: PluginClasses,
                useFactory: ɵ2,
                deps: [PLUGIN_CONFIG, EDITOR_JS_TOOL_INJECTOR]
            },
            NgxEditorJSPluginService
        ]
    })
], NgxEditorJSPluginServiceModule);

/**
 * The `NgxEditorjsPluginsModule` provides several additional modules
 * that provide a way to easily plug in block and inline tools for EditorJS.
 *
 * Importing `NgxEditorjsPluginsModule` will include all modules, while it
 * is also possible to import each individual module as required.
 */
let NgxEditorjsPluginsModule = class NgxEditorjsPluginsModule {
};
NgxEditorjsPluginsModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            NgxEditorJSPluginServiceModule,
            PluginCodeModule,
            PluginHeaderModule,
            PluginImageModule,
            PluginLinkModule,
            PluginListModule,
            PluginMarkerModule,
            PluginParagraphModule,
            PluginSimpleImageModule,
            PluginInlineCodeModule,
            PluginWarningModule,
            PluginQuoteModule,
            PluginEmbedModule
        ],
        exports: [
            NgxEditorJSPluginServiceModule,
            PluginCodeModule,
            PluginHeaderModule,
            PluginImageModule,
            PluginLinkModule,
            PluginListModule,
            PluginMarkerModule,
            PluginParagraphModule,
            PluginSimpleImageModule,
            PluginInlineCodeModule,
            PluginWarningModule,
            PluginQuoteModule,
            PluginEmbedModule
        ]
    })
], NgxEditorjsPluginsModule);

/**
 * Generated bundle index. Do not edit.
 */

export { EDITOR_JS_TOOL_INJECTOR, NgxEditorJSPluginService, NgxEditorJSPluginServiceModule, NgxEditorjsPluginsModule, PLUGIN_CONFIG, PluginClasses, PluginCodeModule, PluginEmbedModule, PluginHeaderModule, PluginImageModule, PluginInlineCodeModule, PluginLinkModule, PluginListModule, PluginMarkerModule, PluginParagraphModule, PluginQuoteModule, PluginSimpleImageModule, PluginTypes, PluginWarningModule, createPluginConfig };
//# sourceMappingURL=tinynodes-ngx-editorjs-plugins.js.map
