import { __decorate, __assign, __read, __param, __metadata } from 'tslib';
import { CommonModule } from '@angular/common';
import { InjectionToken, NgModule, Inject, ɵɵdefineInjectable, ɵɵinject, Injectable } from '@angular/core';
import Code from '@editorjs/code';
import Embed from '@editorjs/embed';
import Header from '@editorjs/header';
import Image from '@editorjs/image';
import InlineCode from '@editorjs/inline-code';
import Link from '@editorjs/link';
import List from '@editorjs/list';
import Marker from '@editorjs/paragraph';
import Quote from '@editorjs/quote';
import SimpleImage from '@editorjs/simple-image';
import Warning from '@editorjs/warning';

/**
 * The types of plugins supported, currently block and inline
 */
var PluginTypes;
(function (PluginTypes) {
    /**
     * A EditorJS block plugin
     */
    PluginTypes["Block"] = "block";
    /**
     * A EditorJS inline plugin
     */
    PluginTypes["Inline"] = "inline";
})(PluginTypes || (PluginTypes = {}));
/**
 * The Injection token for initial plugins as defined in the ngx-editorjs module
 */
var EDITOR_JS_TOOL_INJECTOR = new InjectionToken('EDITOR_JS_TOOL_INJECTOR');
/**
 * Injection token for a plugin config
 */
var PLUGIN_CONFIG = new InjectionToken('PLUGIN_CONFIG');
/**
 * Injection token for the plugin config map
 */
var PluginClasses = new InjectionToken('PluginClasses');

var ɵ0 = Code, ɵ1 = {
    key: 'code',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Code'
};
/**
 * A module that provides the default EditorJS `<code>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/code) for API details
 */
var PluginCodeModule = /** @class */ (function () {
    function PluginCodeModule() {
    }
    PluginCodeModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1,
                    multi: true
                }
            ]
        })
    ], PluginCodeModule);
    return PluginCodeModule;
}());

var ɵ0$1 = Embed, ɵ1$1 = {
    key: 'embed',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Embed Block',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
var PluginEmbedModule = /** @class */ (function () {
    function PluginEmbedModule() {
    }
    PluginEmbedModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$1,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$1,
                    multi: true
                }
            ]
        })
    ], PluginEmbedModule);
    return PluginEmbedModule;
}());

var ɵ0$2 = Header, ɵ1$2 = {
    key: 'header',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Header'
};
/**
 * A module that provides the default EditorJS header block tool.
 * See [the GitHub repo](https://github.com/editor-js/header) for API details
 */
var PluginHeaderModule = /** @class */ (function () {
    function PluginHeaderModule() {
    }
    PluginHeaderModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$2,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$2,
                    multi: true
                }
            ]
        })
    ], PluginHeaderModule);
    return PluginHeaderModule;
}());

var ɵ0$3 = Image, ɵ1$3 = {
    key: 'image',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Image'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
var PluginImageModule = /** @class */ (function () {
    function PluginImageModule() {
    }
    PluginImageModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$3,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$3,
                    multi: true
                }
            ]
        })
    ], PluginImageModule);
    return PluginImageModule;
}());

var ɵ0$4 = InlineCode, ɵ1$4 = {
    key: 'inline-code',
    type: PluginTypes.Inline,
    pluginName: 'EditorJS Inline Code',
    shortcut: 'CTRL+SHIFT+C'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
var PluginInlineCodeModule = /** @class */ (function () {
    function PluginInlineCodeModule() {
    }
    PluginInlineCodeModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$4,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$4,
                    multi: true
                }
            ]
        })
    ], PluginInlineCodeModule);
    return PluginInlineCodeModule;
}());

var ɵ0$5 = Link, ɵ1$5 = {
    key: 'link',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Link'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
var PluginLinkModule = /** @class */ (function () {
    function PluginLinkModule() {
    }
    PluginLinkModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$5,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$5,
                    multi: true
                }
            ]
        })
    ], PluginLinkModule);
    return PluginLinkModule;
}());

var ɵ0$6 = List, ɵ1$6 = {
    key: 'list',
    type: PluginTypes.Block,
    pluginName: 'EditorJS List'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
var PluginListModule = /** @class */ (function () {
    function PluginListModule() {
    }
    PluginListModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$6,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$6,
                    multi: true
                }
            ]
        })
    ], PluginListModule);
    return PluginListModule;
}());

var ɵ0$7 = Marker, ɵ1$7 = {
    key: 'paragraph',
    type: PluginTypes.Inline,
    pluginName: 'EditorJS Marker',
    shortcut: 'CTRL+SHIFT+M'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
var PluginMarkerModule = /** @class */ (function () {
    function PluginMarkerModule() {
    }
    PluginMarkerModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$7,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$7,
                    multi: true
                }
            ]
        })
    ], PluginMarkerModule);
    return PluginMarkerModule;
}());

var ɵ0$8 = Marker, ɵ1$8 = {
    key: 'paragraph',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Paragraph'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
var PluginParagraphModule = /** @class */ (function () {
    function PluginParagraphModule() {
    }
    PluginParagraphModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$8,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$8,
                    multi: true
                }
            ]
        })
    ], PluginParagraphModule);
    return PluginParagraphModule;
}());

var ɵ0$9 = Quote, ɵ1$9 = {
    key: 'quote',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Quote Tool',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
var PluginQuoteModule = /** @class */ (function () {
    function PluginQuoteModule() {
    }
    PluginQuoteModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$9,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$9,
                    multi: true
                }
            ]
        })
    ], PluginQuoteModule);
    return PluginQuoteModule;
}());

var ɵ0$a = SimpleImage, ɵ1$a = {
    key: 'simpleimage',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Simple Image'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
var PluginSimpleImageModule = /** @class */ (function () {
    function PluginSimpleImageModule() {
    }
    PluginSimpleImageModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$a,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$a,
                    multi: true
                }
            ]
        })
    ], PluginSimpleImageModule);
    return PluginSimpleImageModule;
}());

var ɵ0$b = Warning, ɵ1$b = {
    key: 'warning',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Warning Block',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
var PluginWarningModule = /** @class */ (function () {
    function PluginWarningModule() {
    }
    PluginWarningModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ0$b,
                    multi: true
                },
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ1$b,
                    multi: true
                }
            ]
        })
    ], PluginWarningModule);
    return PluginWarningModule;
}());

/**
 * Factory function to create the plugin config map for the plugin service
 * @param pluginConfigs The array of plugin configuration objects passed to this factory
 * @param plugins The array of `EditorJS` plugins that are passed to this factory
 */
function createPluginConfig(pluginConfigs, plugins) {
    return pluginConfigs.reduce(function (pluginConfig, config, index) {
        var _a;
        return typeof config === 'undefined'
            ? pluginConfig
            : __assign(__assign({}, pluginConfig), (_a = {}, _a[config.key] = __assign(__assign({}, config), { plugin: plugins[index] }), _a));
    }, {});
}

/**
 * The `NgxEditorJSPluginService` is provided as a root service for handling {@link https://github.com/editor-js | EditorJS plugins}.
 *
 * Plugins are provided by using {@link https://angular.io/api/core/NgModule | NgModule} to inject the plugin with a
 * {@link ../interfaces/PluginConfig.html | PluginConfig} using providers.
 */
var NgxEditorJSPluginService = /** @class */ (function () {
    /**
     * @param pluginConfigMap The plugin configuration map injected into the application
     */
    function NgxEditorJSPluginService(pluginConfigMap) {
        this.pluginConfigMap = pluginConfigMap;
    }
    /**
     * Get a map of all plugin configurations
     * @returns The map of plugins injected into this plugin
     */
    NgxEditorJSPluginService.prototype.getPlugins = function () {
        return this.pluginConfigMap;
    };
    /**
     * Get a plugin configuration via it's key
     * @param key The key of the plugin to get
     * @returns The plugin configuration for the passed key
     */
    NgxEditorJSPluginService.prototype.getPlugin = function (key) {
        return this.pluginConfigMap[key];
    };
    /**
     * Get a list of plugins, filtering with an exclude list of plugins
     * @param excludeList
     */
    NgxEditorJSPluginService.prototype.getPluginsWithExclude = function (excludeList) {
        if (excludeList === void 0) { excludeList = []; }
        return Object.entries(this.pluginConfigMap)
            .filter(function (_a) {
            var _b = __read(_a, 1), key = _b[0];
            return !excludeList.includes(key);
        })
            .reduce(function (pluginMap, _a) {
            var _b;
            var _c = __read(_a, 2), key = _c[0], plugin = _c[1];
            return __assign(__assign({}, pluginMap), (_b = {}, _b[key] = plugin, _b));
        }, {});
    };
    /**
     * Get a list of plugins, filtering with an include list of plugins
     * @param includeList
     */
    NgxEditorJSPluginService.prototype.getPluginsWithInclude = function (includeList) {
        if (includeList === void 0) { includeList = []; }
        return Object.entries(this.pluginConfigMap)
            .filter(function (_a) {
            var _b = __read(_a, 1), key = _b[0];
            return includeList.includes(key);
        })
            .reduce(function (pluginMap, _a) {
            var _b;
            var _c = __read(_a, 2), key = _c[0], plugin = _c[1];
            return __assign(__assign({}, pluginMap), (_b = {}, _b[key] = plugin, _b));
        }, {});
    };
    /**
     * Returns a map of {@link https://editorjs.io/api | EditorJS} tools to be initialized by the editor
     * @param excludeTools Optional array of tools to exclude, if not passed all tools
     */
    NgxEditorJSPluginService.prototype.getTools = function (excludeTools) {
        if (excludeTools === void 0) { excludeTools = []; }
        return Object.entries(this.getPluginsWithExclude(excludeTools)).reduce(function (finalTools, _a) {
            var _b;
            var _c = __read(_a, 2), key = _c[0], plugin = _c[1];
            var tool = {
                class: plugin.plugin
            };
            if (plugin.shortcut)
                tool.shortcut = plugin.shortcut;
            if (plugin.type === 'inline' || plugin.inlineToolbar)
                tool.inlineToolbar = true;
            if (plugin.config)
                tool.config = plugin.config;
            return __assign(__assign({}, finalTools), (_b = {}, _b[key] = tool, _b));
        }, {});
    };
    NgxEditorJSPluginService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [PluginClasses,] }] }
    ]; };
    NgxEditorJSPluginService.ɵprov = ɵɵdefineInjectable({ factory: function NgxEditorJSPluginService_Factory() { return new NgxEditorJSPluginService(ɵɵinject(PluginClasses)); }, token: NgxEditorJSPluginService, providedIn: "root" });
    NgxEditorJSPluginService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(PluginClasses)),
        __metadata("design:paramtypes", [Object])
    ], NgxEditorJSPluginService);
    return NgxEditorJSPluginService;
}());

var ɵ0$c = undefined, ɵ1$c = undefined, ɵ2 = createPluginConfig;
var NgxEditorJSPluginServiceModule = /** @class */ (function () {
    function NgxEditorJSPluginServiceModule() {
    }
    NgxEditorJSPluginServiceModule = __decorate([
        NgModule({
            providers: [
                {
                    provide: PLUGIN_CONFIG,
                    useValue: ɵ0$c,
                    multi: true
                },
                {
                    provide: EDITOR_JS_TOOL_INJECTOR,
                    useValue: ɵ1$c,
                    multi: true
                },
                {
                    provide: PluginClasses,
                    useFactory: ɵ2,
                    deps: [PLUGIN_CONFIG, EDITOR_JS_TOOL_INJECTOR]
                },
                NgxEditorJSPluginService
            ]
        })
    ], NgxEditorJSPluginServiceModule);
    return NgxEditorJSPluginServiceModule;
}());

/**
 * The `NgxEditorjsPluginsModule` provides several additional modules
 * that provide a way to easily plug in block and inline tools for EditorJS.
 *
 * Importing `NgxEditorjsPluginsModule` will include all modules, while it
 * is also possible to import each individual module as required.
 */
var NgxEditorjsPluginsModule = /** @class */ (function () {
    function NgxEditorjsPluginsModule() {
    }
    NgxEditorjsPluginsModule = __decorate([
        NgModule({
            imports: [
                CommonModule,
                NgxEditorJSPluginServiceModule,
                PluginCodeModule,
                PluginHeaderModule,
                PluginImageModule,
                PluginLinkModule,
                PluginListModule,
                PluginMarkerModule,
                PluginParagraphModule,
                PluginSimpleImageModule,
                PluginInlineCodeModule,
                PluginWarningModule,
                PluginQuoteModule,
                PluginEmbedModule
            ],
            exports: [
                NgxEditorJSPluginServiceModule,
                PluginCodeModule,
                PluginHeaderModule,
                PluginImageModule,
                PluginLinkModule,
                PluginListModule,
                PluginMarkerModule,
                PluginParagraphModule,
                PluginSimpleImageModule,
                PluginInlineCodeModule,
                PluginWarningModule,
                PluginQuoteModule,
                PluginEmbedModule
            ]
        })
    ], NgxEditorjsPluginsModule);
    return NgxEditorjsPluginsModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { EDITOR_JS_TOOL_INJECTOR, NgxEditorJSPluginService, NgxEditorJSPluginServiceModule, NgxEditorjsPluginsModule, PLUGIN_CONFIG, PluginClasses, PluginCodeModule, PluginEmbedModule, PluginHeaderModule, PluginImageModule, PluginInlineCodeModule, PluginLinkModule, PluginListModule, PluginMarkerModule, PluginParagraphModule, PluginQuoteModule, PluginSimpleImageModule, PluginTypes, PluginWarningModule, createPluginConfig };
//# sourceMappingURL=tinynodes-ngx-editorjs-plugins.js.map
